@@ -9,6 +9,7 @@ from typing import TYPE_CHECKING, Any, Mapping
 
 from pdm.formats.base import make_array
 from pdm.models.requirements import FileRequirement, Requirement, parse_requirement
+from pdm.models.specifiers import get_specifier
 from pdm.utils import expand_env_vars_in_auth
 
 if TYPE_CHECKING:
@@ -184,7 +185,7 @@ def export(
     lines = ["# This file is @generated by PDM.\n# Please do not edit it manually.\n\n"]
     for candidate in sorted(candidates, key=lambda x: x.identify()):  # type: ignore[attr-defined]
         if isinstance(candidate, Candidate):
-            req = dataclasses.replace(candidate.req, specifier=f"=={candidate.version}", marker=None)
+            req = dataclasses.replace(candidate.req, specifier=get_specifier(f"=={candidate.version}"), marker=None)
         else:
             assert isinstance(candidate, Requirement)
             req = candidate
