@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 import copy
 import itertools
 import operator
 from functools import reduce
-from typing import Any, List, Optional, Set, Tuple, Union
+from typing import Any
 
 from packaging.markers import Marker as PackageMarker
 
@@ -13,7 +15,7 @@ from pdm.utils import join_list_with
 class Marker(PackageMarker):
     """A subclass of Marker that supports union and intersection merging."""
 
-    def copy(self) -> "Marker":
+    def copy(self) -> Marker:
         inst = self.__class__('os_name == "nt"')
         inst._markers = copy.deepcopy(self._markers)
         return inst
@@ -23,22 +25,14 @@ class Marker(PackageMarker):
             return False
         return str(self) == str(other)
 
-    def split_pyspec(self) -> Tuple[Optional["Marker"], PySpecSet]:
+    def split_pyspec(self) -> tuple[Marker | None, PySpecSet]:
         """Split `python_version` and `python_full_version` from marker string"""
         if _only_contains_python_keys(self._markers):
             return None, _build_pyspec_from_marker(self._markers)
         if "or" in self._markers:
             return self.copy(), PySpecSet()
-        py_markers = [
-            marker
-            for marker in self._markers
-            if marker != "and" and _only_contains_python_keys(marker)
-        ]
-        rest = [
-            marker
-            for marker in self._markers
-            if marker != "and" and marker not in py_markers
-        ]
+        py_markers = [marker for marker in self._markers if marker != "and" and _only_contains_python_keys(marker)]
+        rest = [marker for marker in self._markers if marker != "and" and marker not in py_markers]
         new_markers = join_list_with(rest, "and")
         if not new_markers:
             marker = None
@@ -48,17 +42,17 @@ class Marker(PackageMarker):
         return marker, _build_pyspec_from_marker(join_list_with(py_markers, "and"))
 
 
-def get_marker(marker: Union[PackageMarker, Marker, None]) -> Optional[Marker]:
+def get_marker(marker: PackageMarker | Marker | None) -> Marker | None:
     return Marker(str(marker)) if marker else None
 
 
-def split_marker_extras(marker: str) -> Tuple[Set[str], str]:
+def split_marker_extras(marker: str) -> tuple[set[str], str]:
     """An element can be stripped from the marker only if all parts are connected
     with `and` operator. The rest part are returned as a string or `None` if all are
     stripped.
     """
 
-    def extract_extras(submarker: Union[tuple, list]) -> Set[str]:
+    def extract_extras(submarker: tuple | list) -> set[str]:
         if isinstance(submarker, tuple):
             if submarker[0].value == "extra":
                 if submarker[1].value == "==":
@@ -88,7 +82,7 @@ def split_marker_extras(marker: str) -> Tuple[Set[str], str]:
         return set(), marker
 
     extras = set()
-    submarkers_no_extras: List[Union[tuple, list]] = []
+    submarkers_no_extras: list[tuple | list] = []
     # Below this point the submarkers are connected with 'and'
     for submarker in submarkers:
         if submarker == "and":
@@ -108,7 +102,7 @@ def split_marker_extras(marker: str) -> Tuple[Set[str], str]:
     return extras, str(new_marker)
 
 
-def _only_contains_python_keys(markers: List[Any]) -> bool:
+def _only_contains_python_keys(markers: list[Any]) -> bool:
     if isinstance(markers, tuple):
         return markers[0].value in ("python_version", "python_full_version")
 
@@ -120,8 +114,8 @@ def _only_contains_python_keys(markers: List[Any]) -> bool:
     return True
 
 
-def _build_pyspec_from_marker(markers: List[Any]) -> PySpecSet:
-    def split_version(version: str) -> List[str]:
+def _build_pyspec_from_marker(markers: list[Any]) -> PySpecSet:
+    def split_version(version: str) -> list[str]:
         if "," in version:
             return [v.strip() for v in version.split(",")]
         return version.split()
@@ -136,6 +130,8 @@ def _build_pyspec_from_marker(markers: List[Any]) -> PySpecSet:
             if key == "python_version":
                 if op == ">":
                     int_versions = [int(ver) for ver in version.split(".")]
+                    if len(int_versions) < 2:
+                        int_versions.append(0)
                     int_versions[-1] += 1
                     version = ".".join(str(v) for v in int_versions)
                     op = ">="
@@ -145,13 +141,9 @@ def _build_pyspec_from_marker(markers: List[Any]) -> PySpecSet:
                 elif op in ("in", "not in"):
                     version = " ".join(v + ".*" for v in split_version(version))
             if op == "in":
-                pyspec = reduce(
-                    operator.or_, (PySpecSet(f"=={v}") for v in split_version(version))
-                )
+                pyspec = reduce(operator.or_, (PySpecSet(f"=={v}") for v in split_version(version)))
             elif op == "not in":
-                pyspec = reduce(
-                    operator.and_, (PySpecSet(f"!={v}") for v in split_version(version))
-                )
+                pyspec = reduce(operator.and_, (PySpecSet(f"!={v}") for v in split_version(version)))
             else:
                 pyspec = PySpecSet(f"{op}{version}")
             groups[-1] = groups[-1] & pyspec
